@@ -14,12 +14,14 @@ done
 [[ "$m" == "ia32" ]] && m=x86
 source "$(dirname "$0")/setup.sh"
 
+git clone https://chromium.googlesource.com/external/gyp
+
 # Install GYP.
 pushd gyp
-python -m virtualenv test-env
+python -m venv ./test-env
 test-env/Scripts/python setup.py install
 test-env/Scripts/python -m pip install --upgrade pip
-test-env/Scripts/pip install --upgrade 'setuptools<45.0.0'
+test-env/Scripts/pip install --upgrade 'setuptools<45.0.0' six
 # Fool GYP.
 touch "${VSPATH}/VC/vcvarsall.bat"
 export GYP_MSVS_OVERRIDE_PATH="${VSPATH}"
@@ -38,6 +40,11 @@ if [[ -f ../nss/nspr.patch && "$ALLOW_NSPR_PATCH" == "1" ]]; then
 fi
 popd
 
+make () {
+	mozmake "$@"
+}
+export -f make
+
 # Build with gyp.
 ./nss/build.sh -g -v --enable-libpkix -Denable_draft_hpke=1 "$@"
 
