@@ -33,9 +33,11 @@ class PacketFilter {
     CHANGE,  // change the packet to a different value
     DROP     // drop the packet
   };
-  PacketFilter(bool enabled = true) : enabled_(enabled) {}
+  explicit PacketFilter(bool on = true) : enabled_(on) {}
   virtual ~PacketFilter() {}
 
+  bool enabled() const { return enabled_; }
+
   virtual Action Process(const DataBuffer& input, DataBuffer* output) {
     if (!enabled_) {
       return KEEP;
@@ -65,8 +67,9 @@ class DummyPrSocket : public DummyIOLayerMethods {
         peer_(),
         input_(),
         filter_(nullptr),
-        write_error_(0) {}
-  virtual ~DummyPrSocket() {}
+        write_error_(0),
+        receivedData_() {}
+  virtual ~DummyPrSocket();
 
   static PRDescIdentity LayerId();
 
@@ -115,6 +118,8 @@ class DummyPrSocket : public DummyIOLayerMethods {
   std::queue<Packet> input_;
   std::shared_ptr<PacketFilter> filter_;
   PRErrorCode write_error_;
+
+  std::vector<uint8_t> receivedData_;
 };
 
 // Marker interface.
