@@ -94,8 +94,7 @@ static PK11SlotList
     pk11_tlsSlotList,
     pk11_randomSlotList,
     pk11_sha256SlotList,
-    pk11_sha512SlotList, /* slots do SHA512 and SHA384 */
-    pk11_kyberSlotList;
+    pk11_sha512SlotList; /* slots do SHA512 and SHA384 */
 
 /************************************************************
  * Generic Slot List and Slot List element manipulations
@@ -850,7 +849,6 @@ PK11_InitSlotLists(void)
     pk11_InitSlotListStatic(&pk11_randomSlotList);
     pk11_InitSlotListStatic(&pk11_sha256SlotList);
     pk11_InitSlotListStatic(&pk11_sha512SlotList);
-    pk11_InitSlotListStatic(&pk11_kyberSlotList);
     return SECSuccess;
 }
 
@@ -877,7 +875,6 @@ PK11_DestroySlotLists(void)
     pk11_FreeSlotListStatic(&pk11_randomSlotList);
     pk11_FreeSlotListStatic(&pk11_sha256SlotList);
     pk11_FreeSlotListStatic(&pk11_sha512SlotList);
-    pk11_FreeSlotListStatic(&pk11_kyberSlotList);
     return;
 }
 
@@ -946,7 +943,12 @@ PK11_GetSlotList(CK_MECHANISM_TYPE type)
         case CKM_ECDSA:
         case CKM_ECDSA_SHA1:
         case CKM_EC_KEY_PAIR_GEN: /* aka CKM_ECDSA_KEY_PAIR_GEN */
+        case CKM_NSS_ECDHE_NO_PAIRWISE_CHECK_KEY_PAIR_GEN:
         case CKM_ECDH1_DERIVE:
+        case CKM_NSS_KYBER_KEY_PAIR_GEN: /* Bug 1893029 */
+        case CKM_NSS_KYBER:
+        case CKM_NSS_ML_KEM_KEY_PAIR_GEN: /* Bug 1893029 */
+        case CKM_NSS_ML_KEM:
             return &pk11_ecSlotList;
         case CKM_SSL3_PRE_MASTER_KEY_GEN:
         case CKM_SSL3_MASTER_KEY_DERIVE:
@@ -962,8 +964,6 @@ PK11_GetSlotList(CK_MECHANISM_TYPE type)
             return &pk11_ideaSlotList;
         case CKM_FAKE_RANDOM:
             return &pk11_randomSlotList;
-        case CKM_NSS_KYBER_KEY_PAIR_GEN:
-            return &pk11_kyberSlotList;
     }
     return NULL;
 }
